<?PHP
/**
 * Constains lists for categorizing misspelled damage types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing misspelled damage types.
 */
final class MDConcDamageTypes implements MDImporterConcordanceListInterface {

    private const DAMAGE_TYPES = [
        "breakage" => MDObjectDamageType::breakage,
        "Wasserschaden" => MDObjectDamageType::water_damage,
        "Austrocknung" => MDObjectDamageType::desiccation,
        "Desiccation" => MDObjectDamageType::desiccation,
    ];

    private const DAMAGE_TYPES_BLACKLIST = [
        'keine',
    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return MDObjectDamageType
     */
    public static function getConcordanceTarget(string $input):MDObjectDamageType {

        if (!isset(self::DAMAGE_TYPES[$input])) {

            if (in_array($input, self::DAMAGE_TYPES_BLACKLIST, true)) {
                throw new MDImporterBlacklistedConcordanceTerm("Invalid damage type: " . $input);
            }

            throw new MDImporterMissingConcordance("Unknown damage type: " . $input);
        }

        return self::DAMAGE_TYPES[$input];

    }
}
